@@ -41,8 +41,10 @@ class DbTex:
             self.set_base(base)
         self.xslopts = []
         self.xslparams = []
-        self.xsluser = ""
+        self.xslusers = []
         self.flags = self.USE_MKLISTINGS
+        self.stdindir = ""
+        self.inputdir = ""
         self.input = ""
         self.input_format = "xml"
         self.output = ""
@@ -120,7 +122,7 @@ class DbTex:
             return "unknown"
 
     def build_stylesheet(self, wrapper="custom.xsl"):
-        if not(self.xslparams or self.xsluser):
+        if not(self.xslparams or self.xslusers):
             self.xslbuild = self.xslmain
             return
 
@@ -131,8 +133,8 @@ class DbTex:
                 version="1.0">
                 \n""")
         f.write('<xsl:import href="%s"/>\n' % path_to_uri(self.xslmain))
-        if self.xsluser:
-            f.write('<xsl:import href="%s"/>\n' % path_to_uri(self.xsluser))
+        for xsluser in self.xslusers:
+            f.write('<xsl:import href="%s"/>\n' % path_to_uri(xsluser))
 
         for param in self.xslparams:
             v = param.split("=", 1)
@@ -216,7 +218,10 @@ class DbTex:
         self.set_xslt()
         self.cwdir = os.getcwd()
         self.tmpdir = self.tmpdir_user or tempfile.mkdtemp()
-        self.inputdir = os.path.dirname(self.input)
+        if self.input:
+            self.inputdir = os.path.dirname(self.input)
+        else:
+            self._stdin_write()
         os.chdir(self.tmpdir)
         try:
             donefile = self._compile()
@@ -229,6 +234,17 @@ class DbTex:
             else:
                 print "%s not removed" % self.tmpdir
 
+    def _stdin_write(self):
+        # Find out the stdin working directory
+        self.inputdir = self.stdindir or self.cwdir
+
+        # Need to dump the stdin input, because of the two passes
+        self.input = os.path.join(self.tmpdir, "stdin.xml")
+        f = open(self.input, "w")
+        for line in sys.stdin:
+            f.write(line)
+        f.close()
+
     def _compile(self):
         # The temporary output file
         tmpout = os.path.basename(self.input)
@@ -284,20 +300,22 @@ class DbTexCommand:
         usage = "%s [options] file" % prog
         parser = OptionParser(usage=usage)
         parser.add_option("-b", "--backend",
-                          help="Backend driver to use. The available drivers are "
-                               "'pdftex' and 'dvips'.")
+                          help="Backend driver to use. The available drivers"
+                               " are 'pdftex' (default), 'dvips' and 'xetex'.")
         parser.add_option("-B", "--no-batch", action="store_true",
                           help="All the tex output is printed")
         parser.add_option("-c", "-S", "--config",
                           help="Configuration file")
+        parser.add_option("-C", "--changedir",
+                          help="Standard input working directory")
         parser.add_option("-d", "--debug", action="store_true",
                           help="Debug mode. Keep the temporary directory in "
                                "which %s actually works" % prog)
         parser.add_option("-D", "--dump", action="store_true",
                           help="Dump error stack (debug purpose)")
         parser.add_option("-f", "--fig-format",
-                          help="Input figure format, used when not deduced from "
-                               "figure extension")
+                          help="Input figure format, used when not deduced "
+                               "from figure extension")
         parser.add_option("-F", "--input-format",
                           help="Input file format: sgml, xml. (default=xml)")
         parser.add_option("-i", "--texinputs", action="append",
@@ -314,9 +332,10 @@ class DbTexCommand:
         parser.add_option("-m", "--xslt",
                           help="XSLT engine to use. (default=xsltproc)")
         parser.add_option("-o", "--output", dest="output",
-                          help="Output filename. When not used, the input filename "
+                          help="Output filename. "
+                               "When not used, the input filename "
                                "is used, with the suffix of the output format")
-        parser.add_option("-p", "--xsl-user",
+        parser.add_option("-p", "--xsl-user", action="append",
                           help="XSL user configuration file to use")
         parser.add_option("-P", "--param", dest="xslparams",
                           action="append", metavar="PARAM=VALUE",
@@ -426,10 +445,11 @@ class DbTexCommand:
             run.backend = options.backend
 
         if options.xsl_user:
-            xsluser = os.path.realpath(options.xsl_user)
-            if not(os.path.isfile(xsluser)):
-                failed_exit("Error: '%s' does not exist" % options.xsl_user)
-            run.xsluser = xsluser
+            for xfile in options.xsl_user:
+                xsluser = os.path.realpath(xfile)
+                if not(os.path.isfile(xsluser)):
+                    failed_exit("Error: '%s' does not exist" % options.xsl_user)
+                run.xslusers.append(xsluser)
 
         if options.texpost:
             path = os.path.realpath(options.texpost)
@@ -516,7 +536,15 @@ class DbTexCommand:
         # Verbose mode
         run.log = logger(self.prog, run.verbose)
 
-        input = os.path.realpath(args[0])
+        # Data from standard input?
+        if args[0] == "-":
+            if not(options.output):
+                failed_exit("Error: -o expected when input from stdin")
+            input = ""
+            if options.changedir:
+                run.stdindir = os.path.realpath(options.changedir)
+        else:
+            input = os.path.realpath(args[0])
 
         # The output name can be deduced from the input one:
         # /path/to/input.xml -> /path/to/input.{tex|pdf|dvi|ps}
